<?php

class Turbotext
{
	const API_KEY = 'ws7kruplf1cviehjab2xqn0do96tg583zy4m';
	const API_URL = 'https://www.turbotext.ru/api';
	const IMAGE_BASE = 'https://www.turbotext.ru/uploads/';

	const REJECT_TEXT = 'в задании указана униальность по %SERVICE% 100, у вас %UNIQUE%, будьте добры доработать';

	private static $STATUSES = array(3);
	private $error = '';

	private function call($method, $params = [], $noReturn = false)
	{
		$params = array_merge(['api_key' => self::API_KEY, 'action' => $method], $params);
		$params = http_build_query($params);

		$ch = curl_init(self::API_URL);
		curl_setopt($ch, CURLOPT_POST, true);
		curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		$res = curl_exec($ch);
		curl_close($ch);

		if ($noReturn) return false;

		$res = json_decode('[' . $res . ']', true);

		if (empty($res)) {
			$this->error = 'Ошибка при выполнении запроса к апи turbotext';
			return false;
		}

		if (!empty($res[0]['success'])) {
			return $res[0];
		} else {
			if (is_array($res[0]['errors'])) {
				$this->error = implode("\n", $res[0]['errors']);
			} else {
				$this->error = $res[0]['errors'];
			}
			return false;
		}
	}

	public function getOrders()
	{
		$res = $this->call('get_orders');
		if ($res === false) return false;
		$orders = [];
		foreach ($res['orders'] as $item) {
			if (!in_array($item['status'], self::$STATUSES)) continue;
			$orders[] = $item;
		}
		return $orders;
	}

	public function getOrder($id)
	{
		$res = $this->call('get_order', ['order_id' => $id]);
		if ($res === false) return false;

		return ['title' => $res['title'], 'content' => html_entity_decode($res['text']), 'image' => $res['image']];
	}

	public function rejectOrder($id, $text)
	{
		//Log::add('reject turbotext: id='.$id.', text='.$text);
		$this->call('reject_order', ['order_id' => $id, 'text' => $text], true);
	}

	public function acceptOrder($id)
	{
		//Log::add('accept turbotext: id='.$id);
		$this->call('accept_order', ['order_id' => $id], true);
	}

	public function create($title, $cost, $charsFrom, $charsTo, $additional = '')
	{
		$task = "Нужна уникальная статья строго без воды на заданную тему с учетом описанных ниже правил. 

1. Вода в первом абзаце, сразу пишем по теме.
    !!! Также категорически не пишем воду в тексте.
    конкретно в первом абзаце вода - это обычно описание того, о чем будет статья.
Как примеры воды:
    а. Домашние питомцы радуют и вдохновляют. Но при этом еще и оставляют повсюду шерсть. Воспринимать ли это как печальную «обратную сторону медали» от содержания дома милых сердцу зверушек? Нет. Потому что существуют доступные методы, как очистить от шерсти различные материалы.

    б. Как только новогодние праздники проходят, возле мусорников образуется целое скопление елок.

    в. Пример воды в первом абзаце: Сидеть всей семьей дома, играть в настольные игры и пить чай — это здорово и уютно. Но ведь иногда так хочется по-настоящему развлечься с теми, кто тебе дорог. Получить заряд адреналина, двигаться, бегать, прыгать — что угодно, лишь бы выплеснуть свою энергию и получить от этого удовольствие. - вода, пересказ о чем статья

    г. Еще пример, как не надо: Походы по магазинам затягивают. Иногда планируешь потратить час и тысячу рублей, а получается намного больше. Как не поддаваться на уловки и сохранять деньги?

2. Качественные оценки

    знаменитый/известный/культовый актер
    хорошее/отличное/превосходное что-то
    интересный/интригующий/элегантный образ

    пишем без эпитетов и качественных оценок

3. Заголовок и картинку (если она прикреплена к заданию) не нужно дублировать в тексте статьи. Остальные картинки добавляйте сразу в статью. Изображения должны быть без водяных знаков.

4. Не упоминаем любые способы применения лекарственных препаратов, даже для сада/огорода или уборки

5. Не упоминаем никакие торговые марки или производителей. Не обсуждаем/не сравниваем производителей (не хвалим отечественных)

6. Не даем читателю обещаний
это будет сногсшибательно, вы точно убедитесь в этом, а мужчины не смогут мимо пройти такой красоточки

7. Не ссылаемся на ученых, врачей, специалистов и т.д. На другие издения тоже, разве что там классика
Например 'Ученые доказали....'

8. Не ставим прямые призывы не тратить деньги или не обращаться куда-то

Пример: Не обязательно каждую неделю тратить деньги, покупая новенькую щетку

9. Не комментируем цену, не призываем покупать только у проверенных производителей

Пример: 5 советов по выбору штанов, цену среди 5 вообще не рассматриваем


10. Если есть несколько вариантов как сделать то-то - добавляйте изображение к каждому варианту. На примере темы: 5 советов, как украсить торт к детскому празднику: к каждому совету нужна картинка. Или тема \"С чем сочетать джинсы прямого кроя\"  - также нужно по фотке для каждого сочетания для наглядности. Можно вставлять прямо в текст.

11. Каждый подзаголовок должен быть озаглавлен. Максимум можно добавить номер подзага 1 (но не растягиваем символы, как \"совет номер один\" и т.п.)

12. Если в статье есть обращение к читателю, то на вы.

Уникальность проверяем по text.ru, адвего и контент вотч.
Адвего - не ниже 95% по фразам, 100 - по словам - глубокая проверка. Проверяем десктопной утилитой
текст ру - уникальность строго 100%.
контент вотч - 100.
etxt - 100

На уникальность тексты проверяется всегда и тщательно. Если статья не соответствует требованиям - она не принимается.

".$additional;

		$data = [
			'order_title' => $title,
			'order_type' => 1,
			'order_description' => $task,
			'order_size_from' => $charsFrom,
			'order_size_to' => $charsTo,
			'folder_id' => 18687,
			'order_time' => 24,
			'order_price' => intval($cost),
			'order_who_can_work' => 0,
			'order_need_anons' => 0,
			'order_need_corrector' => 0,
			'order_need_unique' => 0,
			'order_need_image' => 1
		];

		$rand = rand(1, 1000);
		if ($rand <= 500) {
			$data['order_who_can_work'] = 2;
			$data['order_who_can_work_value'] = 0;
		}


		$res = $this->call('create_order', $data);
		if ($res === false) return false;
		return $res['order_id'];
		/*
		Log::add('create turbotext: '.print_r($data, true));
		sleep(1);
		return 1;
		*/
	}

	public function folders()
	{
		$res = $this->call('get_folders');
		print_r($res);
	}

	public function getError()
	{
		return $this->error;
	}
}